all_colors: A function providing all unikn colors and base R colors.
Description
all_colors combines the unikn color gradients with the
657 named colors provided by colors of grDevices.
Usage
all_colors(distinct = TRUE)
Arguments
- distinct
Boolean: Return only colors with unique values and names?
Default: distinct = TRUE (i.e., remove duplicate values and names).
Details
The distinct option removes colors with duplicate color values or names.